@@ -47,6 +47,7 @@ AH_JOB *AH_Job_new(const char *name,
   GWEN_XMLNODE *descrNode;
   const char *segCode=NULL;
   const char *paramName;
+  const char *responseName;
   int needsBPD;
   int needTAN;
   int noSysId;
@@ -113,6 +114,12 @@ AH_JOB *AH_Job_new(const char *name,
   noSysId=(atoi(GWEN_XMLNode_GetProperty(node, "nosysid", "0"))!=0);
   noItan=(atoi(GWEN_XMLNode_GetProperty(node, "noitan", "0"))!=0);
   paramName=GWEN_XMLNode_GetProperty(node, "params", "");
+  responseName=GWEN_XMLNode_GetProperty(node, "response", "");
+  free(j->responseName);
+  if (responseName)
+    j->responseName=strdup(responseName);
+  else
+    j->responseName=NULL;
 
   /* get and store segment code for later use in TAN jobs */
   segCode=GWEN_XMLNode_GetProperty(node, "code", "");
@@ -394,6 +401,7 @@ void AH_Job_free(AH_JOB *j) {
       GWEN_StringList_free(j->challengeParams);
       GWEN_StringList_free(j->log);
       GWEN_StringList_free(j->signers);
+      free(j->responseName);
       free(j->code);
       free(j->name);
       free(j->accountId);
@@ -727,6 +735,14 @@ const char *AH_Job_GetCode(const AH_JOB *j) {
 
 
 
+const char *AH_Job_GetResponseName(const AH_JOB *j) {
+  assert(j);
+  assert(j->usage);
+  return j->responseName;
+}
+
+
+
 int AH_Job_GetMinSignatures(const AH_JOB *j){
   assert(j);
   assert(j->usage);
@@ -2474,19 +2490,7 @@ void AH_Job_SetChallengeValue(AH_JOB *j, const AB_VALUE *v) {
 
 
 void AH_Job_ValueToChallengeString(const AB_VALUE *v, GWEN_BUFFER *buf) {
-  char *p;
-  uint32_t pos;
-
-  pos=GWEN_Buffer_GetPos(buf);
-  AB_Value_toHumanReadableString2(v, buf, 2, 0);
-  p=GWEN_Buffer_GetStart(buf)+pos;
-  while(*p) {
-    if (*p=='.') {
-      *p=',';
-      break;
-    }
-    p++;
-  }
+  AB_Value_toHbciString(v, buf);
 }
 
 
